Getting Started
================

:Author: Etienne Robillard <tkadm30@yandex.com>
:Version: 0.6.2
:Last modified: 2017-01-23

This is some quick notes for getting started, assuming you have read already
the INSTALL file.

Basic requirements
-------------------

Basic requirements for a minimal install:

* Python 2.7.9
* Django 1.4 or higher <http://www.djangoproject.com/>
* Mako 0.5 or higher <http://www.makotemplates.org/>
* PythonPaste 1.7.4 or higher <http://pythonpaste.org/paste/>
* ConfigObj 4.7.2 or higher <http://pypi.python.org/pypi/configobj/>
* Cython 0.16 or higher <http://www.cython.org/>
* WebOb 1.7.0
* Gevent 

If building the HTML documentation, you will 
also need `Sphinx <http://sphinx.pocoo.org/>`_.

Development
-----------

For dev, please also get:

* Pycryptopp <http://tahoe-lafs.org/trac/pycryptopp/>
* Demjson <http://deron.meranda.us/python/demjson/>
* Feedparser <http://www.feedparser.org/>
* SQLAlchemy <http://www.sqlalchemy.org/> - For testing and experimentation only
* Elixir <http://elixir.ematia.de/trac/>  - For testing and experimentation only
* MoinMoin 1.8.9 <http://moinmo.in/> - Required by the ``wikiapp`` app

See also
--------

* `Development wiki <http://www.isotopesoftware.ca/wiki/DjangoHotSauce>`_
* `Getting Started Tutorial <http://www.isotopesoftware.ca/wiki/DjangoHotSauce/GettingStarted>`_
